tests Package
=============

:mod:`tests` Package
--------------------

.. automodule:: CMFDefault.tests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_DefaultWorkflow` Module
----------------------------------

.. automodule:: CMFDefault.tests.test_DefaultWorkflow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_DiscussionReply` Module
----------------------------------

.. automodule:: CMFDefault.tests.test_DiscussionReply
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_DiscussionTool` Module
---------------------------------

.. automodule:: CMFDefault.tests.test_DiscussionTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Discussions` Module
------------------------------

.. automodule:: CMFDefault.tests.test_Discussions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Document` Module
---------------------------

.. automodule:: CMFDefault.tests.test_Document
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_DublinCore` Module
-----------------------------

.. automodule:: CMFDefault.tests.test_DublinCore
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Favorite` Module
---------------------------

.. automodule:: CMFDefault.tests.test_Favorite
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_File` Module
-----------------------

.. automodule:: CMFDefault.tests.test_File
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Image` Module
------------------------

.. automodule:: CMFDefault.tests.test_Image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Link` Module
-----------------------

.. automodule:: CMFDefault.tests.test_Link
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_MembershipTool` Module
---------------------------------

.. automodule:: CMFDefault.tests.test_MembershipTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_MetadataTool` Module
-------------------------------

.. automodule:: CMFDefault.tests.test_MetadataTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_NewsItem` Module
---------------------------

.. automodule:: CMFDefault.tests.test_NewsItem
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_Portal` Module
-------------------------

.. automodule:: CMFDefault.tests.test_Portal
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_PropertiesTool` Module
---------------------------------

.. automodule:: CMFDefault.tests.test_PropertiesTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_RegistrationTool` Module
-----------------------------------

.. automodule:: CMFDefault.tests.test_RegistrationTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_SkinnedFolder` Module
--------------------------------

.. automodule:: CMFDefault.tests.test_SkinnedFolder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_SyndicationInfo` Module
----------------------------------

.. automodule:: CMFDefault.tests.test_SyndicationInfo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_SyndicationTool` Module
----------------------------------

.. automodule:: CMFDefault.tests.test_SyndicationTool
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_join` Module
-----------------------

.. automodule:: CMFDefault.tests.test_join
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_utils` Module
------------------------

.. automodule:: CMFDefault.tests.test_utils
    :members:
    :undoc-members:
    :show-inheritance:

